@@ -26,16 +26,16 @@ def get_samples_from_config(config):
     return list(config["samples"].keys())
 
 
-def get_config_from_sample(sample, config):
+def get_config_from_sample(sample, config, forced=False):
     config = config.copy()
     config["sample"] = sample
     config["bam"] = config["samples"][sample]
 
     dir_lca = Path(config["dir"]) / "lca"
 
-    config["path_mismatches_txt"] = str(dir_lca / f"{sample}.mismatches.txt")
-    config["path_mismatches_stat"] = str(dir_lca / f"{sample}.mismatches.stat.txt")
-    config["path_lca"] = str(dir_lca / f"{sample}.lca.txt")
+    config["path_mismatches_txt"] = str(dir_lca / f"{sample}.mismatches.txt.gz")
+    config["path_mismatches_stat"] = str(dir_lca / f"{sample}.mismatches.stat.txt.gz")
+    config["path_lca"] = str(dir_lca / f"{sample}.lca.txt.gz")
     config["path_lca_log"] = str(dir_lca / f"{sample}.log.txt")
 
     return config
