@@ -97,10 +97,17 @@ def fit_single_group(
     fit_result = {}
 
     data = group_to_numpyro_data(config, group)
+    sample = config["sample"]
+    tax_id = group["tax_id"].iloc[0]
 
     with warnings.catch_warnings():
         warnings.filterwarnings("ignore")
-        fit_all, fit_forward, fit_reverse = frequentist.make_fits(fit_result, data)
+        fit_all, fit_forward, fit_reverse = frequentist.make_fits(
+            fit_result,
+            data,
+            sample,
+            tax_id,
+        )
 
     add_count_information(fit_result, config, group, data)
 
@@ -228,6 +235,7 @@ def compute_fits_parallel_Bayesian(config, df_mismatches, N_in_each_group=100):
 
     do_progressbar = config["cores"] == 1 or len(config["samples"]) == 1
 
+    it = grouper(dfs, cores_pr_fit)
     if do_progressbar:
         it = tqdm(
             grouper(dfs, cores_pr_fit),
@@ -317,6 +325,9 @@ def split(strng, sep, pos):
 
 def read_stats(config):
 
+    import gzip
+    from io import StringIO
+
     columns = [
         "tax_id",
         "tax_name",
@@ -330,10 +341,9 @@ def read_stats(config):
         "tax_path",
     ]
 
-    from io import StringIO
 
     # TODO: remove when Thorfinn updates his code
-    with open(config["path_mismatches_stat"], "r") as f:
+    with gzip.open(config["path_mismatches_stat"], "rt") as f:
         data = f.read()
 
     data = data.replace("\t\t", "\t'")
@@ -361,6 +371,13 @@ def read_stats(config):
 
 def compute(config, df_mismatches):
 
+    # filter out tax_id's with 0 k_sum_total
+    tax_ids_to_drop = set(df_mismatches.query("k_sum_total == 0")["tax_id"].unique())
+    if len(tax_ids_to_drop) > 0:
+        logger.debug(f"Dropping the following Tax IDs since k_sum_total == 0:")
+        logger.debug(tax_ids_to_drop)
+    df_mismatches = df_mismatches.query("k_sum_total > 0")
+
     # find unique tax_ids (when compairing the mismatches matrices)
     # such that only those are fitted
     unique, duplicates = compute_duplicates(df_mismatches)
