@@ -9,7 +9,7 @@ from multiprocessing import current_process
 # import json
 from collections import Counter
 from metaDMG.loggers.loggers import setup_logger
-from metaDMG.errors import metadamageError, Error
+from metaDMG.errors import metadamageError, Error, MismatchFileError
 from metaDMG.fit import mismatches, fits, results
 
 #%%
@@ -87,12 +87,13 @@ def get_LCA_mismatches_command(config):
 
 
 def move_files(config):
+
     sample = config["sample"]
 
     d_move_source_target = {
-        f"{sample}.bdamage.gz.uglyprint.mismatch.txt": config["path_mismatches_txt"],
-        f"{sample}.bdamage.gz.uglyprint.stat.txt": config["path_mismatches_stat"],
-        f"{sample}.lca": config["path_lca"],
+        f"{sample}.bdamage.gz.uglyprint.mismatch.txt.gz": config["path_mismatches_txt"],
+        f"{sample}.bdamage.gz.uglyprint.stat.txt.gz": config["path_mismatches_stat"],
+        f"{sample}.lca.gz": config["path_lca"],
         f"{sample}.log": config["path_lca_log"],
     }
     for source_path, target_path in d_move_source_target.items():
@@ -104,6 +105,7 @@ def move_files(config):
 
 
 def delete_files(config):
+
     sample = config["sample"]
 
     bam = Path(config["bam"]).stem  # .name
@@ -343,22 +345,32 @@ def run_single_config(config):
         logger.error(f"The sample bam file does not exist: {config['bam']}.")
         return None
 
+    forced = config["forced"]
+
     try:
-        run_LCA(config)
+        run_LCA(config, forced=forced)
     except metadamageError:
         logger.exception(
             f"{config['sample']} | metadamageError with run_LCA. "
-            f"See log-file for more information"
+            f"See log-file for more information."
         )
         return None
     except KeyboardInterrupt:
         logger.info("Got KeyboardInterrupt. Cleaning up.")
         delete_all_sample_files(config)
+        raise KeyboardInterrupt
+
+    try:
+        df_mismatches = get_df_mismatches(config, forced=forced)
+    except MismatchFileError:
+        logger.exception(
+            f"{config['sample']} | MismatchFileError with get_df_mismatches. "
+            f"See log-file for more information."
+        )
         return None
 
-    df_mismatches = get_df_mismatches(config)
-    df_fit_results = get_df_fit_results(config, df_mismatches)
-    df_results = get_df_results(config, df_mismatches, df_fit_results)
+    df_fit_results = get_df_fit_results(config, df_mismatches, forced=forced)
+    df_results = get_df_results(config, df_mismatches, df_fit_results, forced=forced)
     # read_ids_mapping = get_database_read_ids(config)
 
     logger.info("Finished.")
